module Debate.Arguments.Inferences.AgriculturalPredation exposing (..)

import Debate.Arguments.Types exposing (..)


argumentAgriculturalPredation : Argument
argumentAgriculturalPredation =
    { argumentTitle = "Argument for Animal Agirculture as Predation"
    , propositionTitle = "Animal agriculture counts as predation."
    , propositionReductio = ""
    , propositionSummary = "Some vegans suggest that killing odd order predators is wrong because predation is permissible. However, if animal agriculture also counts as predation, it's analytically entailed that animal agriculture is permissible as well."
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y~6z(Px~4Qxyz~1(Rxyz~2Sxyz)~1Wxyz)),(Qahl),(Rahl~2Sahl),(Wahl)%7C=(Pa)"
    , argumentCertainty = 10
    , argumentImage = "predatoragriculture"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) counts as predation"
          }
        , { definiendum = "Q(x,y,z)"
          , definiens = "(x) involves a (y) regularly capturing a (z)"
          }
        , { definiendum = "R(x,y,z)"
          , definiens = "(x) involves a (y) regularly killing a (z)"
          }
        , { definiendum = "S(x,y,z)"
          , definiens = "(x) involves a (y) regularly subduing a (z)"
          }
        , { definiendum = "W(x,y,z)"
          , definiens = "(x) involves a (y) regularly consuming, to the captor's benefit, a (z)"
          }
        , { definiendum = "x"
          , definiens = "an action"
          }
        , { definiendum = "y"
          , definiens = "an animal"
          }
        , { definiendum = "z"
          , definiens = "another animal"
          }
        , { definiendum = "a"
          , definiens = "animal agriculture"
          }
        , { definiendum = "h"
          , definiens = "humans"
          }
        , { definiendum = "l"
          , definiens = "livestock"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Something counts as predation if, and only if, something involves an animal regularly capturing, killing or subduing, and consuming, to the captor's benefit, another animal."
                  , notation = "∀x∀y∀z(Px↔Qxyz∧(Rxyz∨Sxyz)∧Wxyz)"
                  }
                , { premise = "Animal agriculture involves humans regularly capturing livestock."
                  , notation = "Qahl"
                  }
                , { premise = "Animal agriculture involves humans regularly killing or subduing livestock."
                  , notation = "Rahl∨Sahl"
                  }
                , { premise = "Animal agriculture involves humans regularly consuming, to the captors' benefit, livestock."
                  , notation = "Wahl"
                  }
                ]
          , conclusion = "Therefore, animal agriculture counts as predation."
          , conclusionNotation = "Pa"
          }
        ]
    }
