module Debate.Arguments.Inferences.OddOrderPredators exposing (..)

import Debate.Arguments.Types exposing (..)


argumentOddOrderPredators : Argument
argumentOddOrderPredators =
    { argumentTitle = "Argument for Culling Odd Order Predators"
    , propositionTitle = "It is permissible to prevent predation with lethal force to the same degree we would tolerate for humans."
    , propositionReductio = "I view animal rights as the logical extension of trait-adjusted human rights to non-human animals. I think humans have the right not to be exposed to circumstances where they're hunted for food, and I think it is permissible to use lethal force to save the lives of the hunted, all else equal. By extension I think non-human animals have this right too."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5~3Qx)),(Pa),(~3Qa~5R)%7C=(R)"
    , argumentCertainty = 10
    , argumentImage = "oddorderpredators"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has negative rights"
          }
        , { definiendum = "Q(x)"
          , definiens = "we should defend (x) from rights violations to any lesser degree than we would tolerate for humans"
          }
        , { definiendum = "R(x)"
          , definiens = "it is permissible to prevent predation with lethal force to the same degree we would tolerate for humans"
          }
        , { definiendum = "x"
          , definiens = "a being"
          }
        , { definiendum = "a"
          , definiens = "animal"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if something has negative rights, then we should not defend it from rights violations to any lesser degree than we would tolerate for humans."
                  , notation = "∀x(Px→¬Qx)"
                  }
                , { premise = "Animals have negative rights."
                  , notation = "Pa"
                  }
                , { premise = "If we should not defend animals from rights violations to any lesser degree than we would tolerate for humans, then it is permissible to prevent predation with lethal force to the same degree we would tolerate for humans."
                  , notation = "¬Qa→R"
                  }
                ]
          , conclusion = "Therefore, it is permissible to prevent predation with lethal force to the same degree we would tolerate for humans."
          , conclusionNotation = "R"
          }
        ]
    }
