module Home.Helpers exposing (..)

import Blog.Helpers exposing (..)
import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Config.Response exposing (..)
import Config.Style.Svgs exposing (..)
import Config.Viewport exposing (..)
import Effect exposing (Effect)
import Element as E exposing (..)
import Element.Background as B exposing (..)
import Element.Border as D exposing (..)
import Element.Font as F
import Html exposing (Html)
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared exposing (..)
import View exposing (View)


homePage : Html msg -> Element msg
homePage image =
    column
        [ centerX
        , centerY
        , spacing 20
        ]
        [ row [ centerX, E.width fill, height <| px 100 ]
            [ html image
            ]
        , column
            [ paddingEach
                { top = 15
                , bottom = 15
                , left = 20
                , right = 20
                }
            , O.glow
            , B.color colourTheme.backgroundDarkGrey
            , rounded 10
            , E.width fill
            , spacing 8
            ]
            [ paragraph (paragraphFormat ++ [ centerX ]) [ text "upRootNutrition is an open source project, created by Nick Hiebert, designed to elevate the quality of nutrition science communication in online discourse. By applying more rigorous systems of reasoning, such as formal logic, upRootNutrition aims to cut through the misinformation and sophistry that are endemic on social media." ]
            ]
        ]


desktopHomePageImage : Html msg
desktopHomePageImage =
    upRootLarge


mobileLargeHomePageImage : Html msg
mobileLargeHomePageImage =
    upRootMedium


mobileSmallHomePageImage : Html msg
mobileSmallHomePageImage =
    upRootSmall


desktopHomePage =
    homePage desktopHomePageImage


mobileLargeHomePage =
    homePage mobileLargeHomePageImage


mobileSmallHomePage =
    homePage mobileSmallHomePageImage
