module Pages.Gibberish exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Config.Response exposing (..)
import Config.Viewport exposing (..)
import Debate.Arguments.Helpers exposing (..)
import Debate.Arguments.Types exposing (..)
import Debate.Gibberish.Domains.Epistemology exposing (epistemologyGibberish)
import Debate.Gibberish.Domains.Metaphysics exposing (metaphysicsGibberish)
import Debate.Gibberish.Domains.Normativity exposing (normativityGibberish)
import Debate.Gibberish.Domains.Ontology exposing (ontologyGibberish)
import Debate.Gibberish.Domains.PhilOfLanguage exposing (philOfLanguageGibberish)
import Debate.Gibberish.Domains.PhilOfMind exposing (philOfMindGibberish)
import Debate.Gibberish.Domains.Theology exposing (theologyGibberish)
import Debate.Gibberish.Helpers exposing (..)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Border as D exposing (..)
import Element.Font as F
import Headers.Helpers exposing (headerMaker)
import Headers.Pages.Gibberish exposing (gibberishHeader)
import Html
import Html.Attributes as H exposing (style, title, wrap)
import Layouts
import List.Extra as L exposing (..)
import Page exposing (Page)
import Route exposing (Route)
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.batch
        [ Effect.map
            (\_ -> NoOp)
            (Effect.sendCmd resetViewport)
        , Effect.none
        ]
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = "debate (" ++ pageNames.pageGibberish ++ ")"
    , attributes = []
    , element = gibberishContainer shared.device
    }


gibberishContainer : Device -> Element msg
gibberishContainer device =
    topLevelContainer (gibberishList device)


gibberishList : Device -> Element msg
gibberishList device =
    column
        (case ( device.class, device.orientation ) of
            _ ->
                pageListDesktop
        )
    <|
        List.concat
            [ List.map headerMaker
                [ gibberishHeader ]
            , (case ( device.class, device.orientation ) of
                ( Phone, Portrait ) ->
                    List.map gibberishMakerMobile

                ( Tablet, Portrait ) ->
                    List.map gibberishMakerMobile

                _ ->
                    List.map gibberishMaker
              )
                [ epistemologyGibberish
                , theologyGibberish
                , metaphysicsGibberish
                , normativityGibberish
                , ontologyGibberish
                , philOfMindGibberish
                , philOfLanguageGibberish
                ]
            ]
